@@ -29,9 +29,13 @@ from octobot_tentacles_manager.api.util import (
 )
 
 from octobot_tentacles_manager.api.uploader import (
+    upload_file_or_folder,
     upload_file_to_nexus,
     upload_folder_to_nexus,
     upload_file_or_folder_to_nexus,
+    upload_file_to_s3,
+    upload_folder_to_s3,
+    upload_file_or_folder_to_s3,
 )
 
 from octobot_tentacles_manager.api.configurator import (
@@ -127,7 +131,11 @@ __all__ = [
     "repair_installation",
     "manage_tentacles",
     "create_all_tentacles_bundle",
+    "upload_file_or_folder",
     "upload_file_to_nexus",
     "upload_folder_to_nexus",
     "upload_file_or_folder_to_nexus",
+    "upload_file_to_s3",
+    "upload_folder_to_s3",
+    "upload_file_or_folder_to_s3",
 ]
